@@ -1,12 +1,7 @@
 <?php
 /**
  * Contain a class for special pages
- * @package MediaWiki
- * @subpackage Search
- */
-
-/**
- * @package MediaWiki
+ * @addtogroup Search
  */
 class SearchEngine {
 	var $limit = 10;
@@ -116,7 +111,7 @@ class SearchEngine {
 		# Entering an IP address goes to the contributions page
 		if ( ( $title->getNamespace() == NS_USER && User::isIP($title->getText() ) )
 			|| User::isIP( trim( $searchterm ) ) ) {
-			return Title::makeTitle( NS_SPECIAL, "Contributions/" . $title->getDbkey() );
+			return SpecialPage::getTitleFor( 'Contributions', $title->getDbkey() );
 		}
 
 
@@ -124,16 +119,33 @@ class SearchEngine {
 		if ( $title->getNamespace() == NS_USER ) {
 			return $title;
 		}
+		
+		# Go to images that exist even if there's no local page.
+		# There may have been a funny upload, or it may be on a shared
+		# file repository such as Wikimedia Commons.
+		if( $title->getNamespace() == NS_IMAGE ) {
+			$image = new Image( $title );
+			if( $image->exists() ) {
+				return $title;
+			}
+		}
+
+		# MediaWiki namespace? Page may be "implied" if not customized.
+		# Just return it, with caps forced as the message system likes it.
+		if( $title->getNamespace() == NS_MEDIAWIKI ) {
+			return Title::makeTitle( NS_MEDIAWIKI, $wgContLang->ucfirst( $title->getText() ) );
+		}
 
 		# Quoted term? Try without the quotes...
+		$matches = array();
 		if( preg_match( '/^"([^"]+)"$/', $searchterm, $matches ) ) {
 			return SearchEngine::getNearMatch( $matches[1] );
 		}
-
+		
 		return NULL;
 	}
 
-	function legalSearchChars() {
+	public static function legalSearchChars() {
 		return "A-Za-z_'0-9\\x80-\\xFF\\-";
 	}
 
@@ -192,9 +204,8 @@ class SearchEngine {
 	 * active database backend, and return a configured instance.
 	 *
 	 * @return SearchEngine
-	 * @private
 	 */
-	function create() {
+	public static function create() {
 		global $wgDBtype, $wgSearchType;
 		if( $wgSearchType ) {
 			$class = $wgSearchType;
@@ -202,6 +213,8 @@ class SearchEngine {
 			$class = 'SearchMySQL4';
 		} else if ( $wgDBtype == 'postgres' ) {
 			$class = 'SearchPostgres';
+		} else if ( $wgDBtype == 'oracle' ) {
+			$class = 'SearchOracle';
 		} else {
 			$class = 'SearchEngineDummy';
 		}
@@ -231,12 +244,15 @@ class SearchEngine {
 	 * @param string $title
 	 * @abstract
 	 */
-    function updateTitle( $id, $title ) {
+	function updateTitle( $id, $title ) {
 		// no-op
-    }
+	}
 }
 
-/** @package MediaWiki */
+
+/**
+ * @addtogroup Search
+ */
 class SearchResultSet {
 	/**
 	 * Fetch an array of regular expression fragments for matching
@@ -311,7 +327,10 @@ class SearchResultSet {
 	}
 }
 
-/** @package MediaWiki */
+
+/**
+ * @addtogroup Search
+ */
 class SearchResult {
 	function SearchResult( $row ) {
 		$this->mTitle = Title::makeTitle( $row->page_namespace, $row->page_title );
@@ -334,7 +353,7 @@ class SearchResult {
 }
 
 /**
- * @package MediaWiki
+ * @addtogroup Search
  */
 class SearchEngineDummy {
 	function search( $term ) {
