@@ -1,8 +1,7 @@
 <?php
 /**
  * Use this special page to get a list of the MediaWiki system messages.
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 
 /**
@@ -89,8 +88,8 @@ function makeHTMLText( $messages ) {
 	global $wgLang, $wgContLang, $wgUser;
 	wfProfileIn( __METHOD__ );
 
-	$sk =& $wgUser->getSkin();
-	$talk = $wgLang->getNsText( NS_TALK );
+	$sk = $wgUser->getSkin();
+	$talk = wfMsg( 'talkpagelinktext' );
 
 	$input = wfElement( 'input', array(
 		'type'    => 'text',
@@ -124,7 +123,7 @@ function makeHTMLText( $messages ) {
 		NS_MEDIAWIKI => array(),
 		NS_MEDIAWIKI_TALK => array()
 	);
-	$dbr =& wfGetDB( DB_SLAVE );
+	$dbr = wfGetDB( DB_SLAVE );
 	$page = $dbr->tableName( 'page' );
 	$sql = "SELECT page_namespace,page_title FROM $page WHERE page_namespace IN (" . NS_MEDIAWIKI . ", " . NS_MEDIAWIKI_TALK . ")";
 	$res = $dbr->query( $sql );
