@@ -19,8 +19,7 @@
 
 /**
  *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 
 /**
@@ -38,18 +37,17 @@ function wfSpecialLog( $par = '' ) {
 
 /**
  *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 class LogReader {
 	var $db, $joinClauses, $whereClauses;
-	var $type = '', $user = '', $title = null;
+	var $type = '', $user = '', $title = null, $pattern = false;
 
 	/**
 	 * @param WebRequest $request For internal use use a FauxRequest object to pass arbitrary parameters.
 	 */
 	function LogReader( $request ) {
-		$this->db =& wfGetDB( DB_SLAVE );
+		$this->db = wfGetDB( DB_SLAVE );
 		$this->setupQuery( $request );
 	}
 
@@ -68,11 +66,15 @@ class LogReader {
 
 		$this->limitType( $request->getVal( 'type' ) );
 		$this->limitUser( $request->getText( 'user' ) );
-		$this->limitTitle( $request->getText( 'page' ) );
+		$this->limitTitle( $request->getText( 'page' ) , $request->getBool( 'pattern' ) );
 		$this->limitTime( $request->getVal( 'from' ), '>=' );
 		$this->limitTime( $request->getVal( 'until' ), '<=' );
 
 		list( $this->limit, $this->offset ) = $request->getLimitOffset();
+		
+		// XXX This all needs to use Pager, ugly hack for now.
+		global $wgMiserMode;
+		if ($wgMiserMode && ($this->offset >10000)) $this->offset=10000;
 	}
 
 	/**
@@ -97,7 +99,7 @@ class LogReader {
 	function limitUser( $name ) {
 		if ( $name == '' )
 			return false;
-		$usertitle = Title::makeTitle( NS_USER, $name );
+		$usertitle = Title::makeTitleSafe( NS_USER, $name );
 		if ( is_null( $usertitle ) )
 			return false;
 		$this->user = $usertitle->getText();
@@ -118,15 +120,22 @@ class LogReader {
 	 * @param string $page Title name as text
 	 * @private
 	 */
-	function limitTitle( $page ) {
+	function limitTitle( $page , $pattern ) {
+		global $wgMiserMode;
 		$title = Title::newFromText( $page );
 		if( empty( $page ) || is_null( $title )  ) {
 			return false;
 		}
 		$this->title =& $title;
-		$safetitle = $this->db->strencode( $title->getDBkey() );
+		$this->pattern = $pattern;
 		$ns = $title->getNamespace();
-		$this->whereClauses[] = "log_namespace=$ns AND log_title='$safetitle'";
+		if ( $pattern && !$wgMiserMode ) {
+			$safetitle = $this->db->escapeLike( $title->getDBkey() ); // use escapeLike to avoid expensive search patterns like 't%st%'
+			$this->whereClauses[] = "log_namespace=$ns AND log_title LIKE '$safetitle%'";
+		} else {
+			$safetitle = $this->db->strencode( $title->getDBkey() );
+			$this->whereClauses[] = "log_namespace=$ns AND log_title = '$safetitle'";
+		}
 	}
 
 	/**
@@ -151,7 +160,6 @@ class LogReader {
 	 */
 	function getQuery() {
 		$logging = $this->db->tableName( "logging" );
-		$user = $this->db->tableName( 'user' );
 		$sql = "SELECT /*! STRAIGHT_JOIN */ log_type, log_action, log_timestamp,
 			log_user, user_name,
 			log_namespace, log_title, page_id,
@@ -190,6 +198,13 @@ class LogReader {
 		return $this->user;
 	}
 
+	/**
+	 * @return boolean The checkbox, if titles should be searched by a pattern too
+	 */
+	function queryPattern() {
+		return $this->pattern;
+	}
+
 	/**
 	 * @return string The text of the title that this LogReader has been limited to.
 	 */
@@ -204,8 +219,7 @@ class LogReader {
 
 /**
  *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 class LogViewer {
 	/**
@@ -219,7 +233,7 @@ class LogViewer {
 	 */
 	function LogViewer( &$reader ) {
 		global $wgUser;
-		$this->skin =& $wgUser->getSkin();
+		$this->skin = $wgUser->getSkin();
 		$this->reader =& $reader;
 	}
 
@@ -231,9 +245,13 @@ class LogViewer {
 		$this->showHeader( $wgOut );
 		$this->showOptions( $wgOut );
 		$result = $this->getLogRows();
-		$this->showPrevNext( $wgOut );
-		$this->doShowList( $wgOut, $result );
-		$this->showPrevNext( $wgOut );
+		if ( $this->numResults > 0 ) {
+			$this->showPrevNext( $wgOut );
+			$this->doShowList( $wgOut, $result );
+			$this->showPrevNext( $wgOut );
+		} else {
+			$this->showError( $wgOut );
+		}
 	}
 
 	/**
@@ -253,8 +271,8 @@ class LogViewer {
 		$batch = new LinkBatch;
 		while ( $s = $result->fetchObject() ) {
 			// User link
-			$title = Title::makeTitleSafe( NS_USER, $s->user_name );
-			$batch->addObj( $title );
+			$batch->addObj( Title::makeTitleSafe( NS_USER, $s->user_name ) );
+			$batch->addObj( Title::makeTitleSafe( NS_USER_TALK, $s->user_name ) );
 
 			// Move destination link
 			if ( $s->log_type == 'move' ) {
@@ -277,34 +295,39 @@ class LogViewer {
 	 * @param OutputPage $out where to send output
 	 */
 	function showList( &$out ) {
-		$this->doShowList( $out, $this->getLogRows() );
+		$result = $this->getLogRows();
+		if ( $this->numResults > 0 ) {
+			$this->doShowList( $out, $result );
+		} else {
+			$this->showError( $out );
+		}
 	}
 
 	function doShowList( &$out, $result ) {
 		// Rewind result pointer and go through it again, making the HTML
-		if ($this->numResults > 0) {
-			$html = "\n<ul>\n";
-			$result->seek( 0 );
-			while( $s = $result->fetchObject() ) {
-				$html .= $this->logLine( $s );
-			}
-			$html .= "\n</ul>\n";
-			$out->addHTML( $html );
-		} else {
-			$out->addWikiText( wfMsg( 'logempty' ) );
+		$html = "\n<ul>\n";
+		$result->seek( 0 );
+		while( $s = $result->fetchObject() ) {
+			$html .= $this->logLine( $s );
 		}
+		$html .= "\n</ul>\n";
+		$out->addHTML( $html );
 		$result->free();
 	}
 
+	function showError( &$out ) {
+		$out->addWikiText( wfMsg( 'logempty' ) );
+	}
+
 	/**
 	 * @param Object $s a single row from the result set
 	 * @return string Formatted HTML list item
 	 * @private
 	 */
 	function logLine( $s ) {
-		global $wgLang;
+		global $wgLang, $wgUser;;
+		$skin = $wgUser->getSkin();
 		$title = Title::makeTitle( $s->log_namespace, $s->log_title );
-		$user = Title::makeTitleSafe( NS_USER, $s->user_name );
 		$time = $wgLang->timeanddate( wfTimestamp(TS_MW, $s->log_timestamp), true );
 
 		// Enter the existence or non-existence of this page into the link cache,
@@ -316,20 +339,43 @@ class LogViewer {
 			$linkCache->addBadLinkObj( $title );
 		}
 
-		$userLink = $this->skin->userLink( $s->log_user, $s->user_name ) . $this->skin->userToolLinks( $s->log_user, $s->user_name );
+		$userLink = $this->skin->userLink( $s->log_user, $s->user_name ) . $this->skin->userToolLinksRedContribs( $s->log_user, $s->user_name );
 		$comment = $this->skin->commentBlock( $s->log_comment );
 		$paramArray = LogPage::extractParams( $s->log_params );
 		$revert = '';
+		// show revertmove link
 		if ( $s->log_type == 'move' && isset( $paramArray[0] ) ) {
-			$specialTitle = Title::makeTitle( NS_SPECIAL, 'Movepage' );
 			$destTitle = Title::newFromText( $paramArray[0] );
 			if ( $destTitle ) {
-				$revert = '(' . $this->skin->makeKnownLinkObj( $specialTitle, wfMsg( 'revertmove' ),
+				$revert = '(' . $this->skin->makeKnownLinkObj( SpecialPage::getTitleFor( 'Movepage' ),
+					wfMsg( 'revertmove' ),
 					'wpOldTitle=' . urlencode( $destTitle->getPrefixedDBkey() ) .
 					'&wpNewTitle=' . urlencode( $title->getPrefixedDBkey() ) .
 					'&wpReason=' . urlencode( wfMsgForContent( 'revertmove' ) ) .
 					'&wpMovetalk=0' ) . ')';
 			}
+		// show undelete link
+		} elseif ( $s->log_action == 'delete' && $wgUser->isAllowed( 'delete' ) ) {
+			$revert = '(' . $this->skin->makeKnownLinkObj( SpecialPage::getTitleFor( 'Undelete' ),
+				wfMsg( 'undeletebtn' ) ,
+				'target='. urlencode( $title->getPrefixedDBkey() ) ) . ')';
+		
+		// show unblock link
+		} elseif ( $s->log_action == 'block' && $wgUser->isAllowed( 'block' ) ) {
+			$revert = '(' .  $skin->makeKnownLinkObj( SpecialPage::getTitleFor( 'Ipblocklist' ),
+				wfMsg( 'unblocklink' ),
+				'action=unblock&ip=' . urlencode( $s->log_title ) ) . ')';
+		// show change protection link
+		} elseif ( $s->log_action == 'protect' && $wgUser->isAllowed( 'protect' ) ) {
+			$revert = '(' .  $skin->makeKnownLink( $title->getPrefixedDBkey() ,
+				wfMsg( 'protect_change' ),
+				'action=unprotect' ) . ')';
+		// show user tool links for self created users
+		} elseif ( $s->log_action == 'create2' ) {
+			$revert = $this->skin->userToolLinksRedContribs( $s->log_user, $s->log_title );
+			// do not show $comment for self created accounts. It includes wrong user tool links:
+			// 'blockip' for users w/o block allowance and broken links for very long usernames (bug 4756)
+			$comment = '';
 		}
 
 		$action = LogPage::actionText( $s->log_type, $s->log_action, $title, $this->skin, $paramArray, true, true );
@@ -354,17 +400,20 @@ class LogViewer {
 	 * @private
 	 */
 	function showOptions( &$out ) {
-		global $wgScript;
+		global $wgScript, $wgMiserMode;
 		$action = htmlspecialchars( $wgScript );
-		$title = Title::makeTitle( NS_SPECIAL, 'Log' );
+		$title = SpecialPage::getTitleFor( 'Log' );
 		$special = htmlspecialchars( $title->getPrefixedDBkey() );
 		$out->addHTML( "<form action=\"$action\" method=\"get\">\n" .
-			"<input type='hidden' name='title' value=\"$special\" />\n" .
-			$this->getTypeMenu() .
-			$this->getUserInput() .
-			$this->getTitleInput() .
-			"<input type='submit' value=\"" . wfMsg( 'allpagessubmit' ) . "\" />" .
-			"</form>" );
+			'<fieldset>' .
+			Xml::element( 'legend', array(), wfMsg( 'log' ) ) .
+			Xml::hidden( 'title', $special ) . "\n" .
+			$this->getTypeMenu() . "\n" .
+			$this->getUserInput() . "\n" .
+			$this->getTitleInput() . "\n" .
+			(!$wgMiserMode?($this->getTitlePattern()."\n"):"") .
+			Xml::submitButton( wfMsg( 'allpagessubmit' ) ) . "\n" .
+			"</fieldset></form>" );
 	}
 
 	/**
@@ -373,12 +422,26 @@ class LogViewer {
 	 */
 	function getTypeMenu() {
 		$out = "<select name='type'>\n";
-		foreach( LogPage::validTypes() as $type ) {
-			$text = htmlspecialchars( LogPage::logName( $type ) );
-			$selected = ($type == $this->reader->queryType()) ? ' selected="selected"' : '';
-			$out .= "<option value=\"$type\"$selected>$text</option>\n";
+
+		$validTypes = LogPage::validTypes();
+		$m = array(); // Temporary array
+
+		// First pass to load the log names
+		foreach( $validTypes as $type ) {
+			$text = LogPage::logName( $type );
+			$m[$text] = $type;
 		}
-		$out .= "</select>\n";
+
+		// Second pass to sort by name
+		ksort($m);
+
+		// Third pass generates sorted XHTML content
+		foreach( $m as $text => $type ) {
+			$selected = ($type == $this->reader->queryType());
+			$out .= Xml::option( $text, $type, $selected ) . "\n";
+		}
+
+		$out .= '</select>';
 		return $out;
 	}
 
@@ -387,8 +450,8 @@ class LogViewer {
 	 * @private
 	 */
 	function getUserInput() {
-		$user = htmlspecialchars( $this->reader->queryUser() );
-		return wfMsg('specialloguserlabel') . "<input type='text' name='user' size='12' value=\"$user\" />\n";
+		$user =  $this->reader->queryUser();
+		return Xml::inputLabel( wfMsg( 'specialloguserlabel' ), 'user', 'user', 12, $user );
 	}
 
 	/**
@@ -396,8 +459,17 @@ class LogViewer {
 	 * @private
 	 */
 	function getTitleInput() {
-		$title = htmlspecialchars( $this->reader->queryTitle() );
-		return wfMsg('speciallogtitlelabel') . "<input type='text' name='page' size='20' value=\"$title\" />\n";
+		$title = $this->reader->queryTitle();
+		return Xml::inputLabel( wfMsg( 'speciallogtitlelabel' ), 'page', 'page', 20, $title );
+	}
+
+	/**
+	 * @return boolean Checkbox
+	 * @private
+	 */
+	function getTitlePattern() {
+		$pattern = $this->reader->queryPattern();
+		return Xml::checkLabel( wfMsg( 'log-title-wildcard' ), 'pattern', 'pattern', $pattern );
 	}
 
 	/**
@@ -410,6 +482,7 @@ class LogViewer {
 		$pieces[] = 'type=' . urlencode( $this->reader->queryType() );
 		$pieces[] = 'user=' . urlencode( $this->reader->queryUser() );
 		$pieces[] = 'page=' . urlencode( $this->reader->queryTitle() );
+		$pieces[] = 'pattern=' . urlencode( $this->reader->queryPattern() );
 		$bits = implode( '&', $pieces );
 		list( $limit, $offset ) = $wgRequest->getLimitOffset();
 
