@@ -1,14 +1,12 @@
 <?php
 /**
  *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 
 /**
- *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * implements Special:Newpages
+ * @addtogroup SpecialPage
  */
 class NewPagesPage extends QueryPage {
 
@@ -41,7 +39,7 @@ class NewPagesPage extends QueryPage {
 	function getSQL() {
 		global $wgUser, $wgUseRCPatrol;
 		$usepatrol = ( $wgUseRCPatrol && $wgUser->isAllowed( 'patrol' ) ) ? 1 : 0;
-		$dbr =& wfGetDB( DB_SLAVE );
+		$dbr = wfGetDB( DB_SLAVE );
 		list( $recentchanges, $page ) = $dbr->tableNamesN( 'recentchanges', 'page' );
 
 		$uwhere = $this->makeUserWhere( $dbr );
@@ -52,9 +50,9 @@ class NewPagesPage extends QueryPage {
 				rc_namespace AS namespace,
 				rc_title AS title,
 				rc_cur_id AS cur_id,
-				rc_user AS user,
+				rc_user AS \"user\",
 				rc_user_text AS user_text,
-				rc_comment as comment,
+				rc_comment as \"comment\",
 				rc_timestamp AS timestamp,
 				rc_timestamp AS value,
 				'{$usepatrol}' as usepatrol,
@@ -133,13 +131,16 @@ class NewPagesPage extends QueryPage {
 	 */	
 	function getPageHeader() {
 		$self = SpecialPage::getTitleFor( $this->getName() );
-		$form = wfOpenElement( 'form', array( 'method' => 'post', 'action' => $self->getLocalUrl() ) );
-		$form .= '<table><tr><td align="right">' . wfMsgHtml( 'namespace' ) . '</td>';
-		$form .= '<td>' . HtmlNamespaceSelector( $this->namespace ) . '</td><tr>';
-		$form .= '<tr><td align="right">' . wfMsgHtml( 'newpages-username' ) . '</td>';
-		$form .= '<td>' . wfInput( 'username', 30, $this->username ) . '</td></tr>';
-		$form .= '<tr><td></td><td>' . wfSubmitButton( wfMsg( 'allpagessubmit' ) ) . '</td></tr></table>';
-		$form .= wfHidden( 'offset', $this->offset ) . wfHidden( 'limit', $this->limit ) . '</form>';
+		$form = Xml::openElement( 'form', array( 'method' => 'post', 'action' => $self->getLocalUrl() ) );
+		# Namespace selector
+		$form .= '<table><tr><td align="right">' . Xml::label( wfMsg( 'namespace' ), 'namespace' ) . '</td>';
+		$form .= '<td>' . Xml::namespaceSelector( $this->namespace ) . '</td></tr>';
+		# Username filter
+		$form .= '<tr><td align="right">' . Xml::label( wfMsg( 'newpages-username' ), 'mw-np-username' ) . '</td>';
+		$form .= '<td>' . Xml::input( 'username', 30, $this->username, array( 'id' => 'mw-np-username' ) ) . '</td></tr>';
+		
+		$form .= '<tr><td></td><td>' . Xml::submitButton( wfMsg( 'allpagessubmit' ) ) . '</td></tr></table>';
+		$form .= Xml::hidden( 'offset', $this->offset ) . Xml::hidden( 'limit', $this->limit ) . '</form>';
 		return $form;
 	}
 	
