@@ -1,19 +1,13 @@
 <?php
 /**
- * A querypage to list the most wanted categories
+ * A querypage to list the most wanted categories - implements Special:Wantedcategories
  *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  *
  * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
  * @copyright Copyright © 2005, Ævar Arnfjörð Bjarmason
  * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License 2.0 or later
  */
-
-/**
- * @package MediaWiki
- * @subpackage SpecialPage
- */
 class WantedCategoriesPage extends QueryPage {
 
 	function getName() { return 'Wantedcategories'; }
@@ -21,7 +15,7 @@ class WantedCategoriesPage extends QueryPage {
 	function isSyndicated() { return false; }
 
 	function getSQL() {
-		$dbr =& wfGetDB( DB_SLAVE );
+		$dbr = wfGetDB( DB_SLAVE );
 		list( $categorylinks, $page ) = $dbr->tableNamesN( 'categorylinks', 'page' );
 		$name = $dbr->addQuotes( $this->getName() );
 		return
