@@ -1,8 +1,7 @@
 <?php
 /**
  *
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 
 /**
@@ -15,15 +14,21 @@ function wfSpecialWhatlinkshere($par = NULL) {
 	$page->execute();
 }
 
+/**
+ * implements Special:Whatlinkshere
+ * @addtogroup SpecialPage
+ */
 class WhatLinksHerePage {
 	var $request, $par;
-	var $limit, $from, $dir, $target;
+	var $limit, $from, $back, $target;
 	var $selfTitle, $skin;
 
+	private $namespace;
+
 	function WhatLinksHerePage( &$request, $par = null ) {
 		global $wgUser;
 		$this->request =& $request;
-		$this->skin =& $wgUser->getSkin();
+		$this->skin = $wgUser->getSkin();
 		$this->par = $par;
 	}
 
@@ -35,10 +40,7 @@ class WhatLinksHerePage {
 			$this->limit = 50;
 		}
 		$this->from = $this->request->getInt( 'from' );
-		$this->dir = $this->request->getText( 'dir', 'next' );
-		if ( $this->dir != 'prev' ) {
-			$this->dir = 'next';
-		}
+		$this->back = $this->request->getInt( 'back' );
 
 		$targetString = isset($this->par) ? $this->par : $this->request->getVal( 'target' );
 
@@ -59,7 +61,7 @@ class WhatLinksHerePage {
 
 		$wgOut->addHTML( wfMsg( 'whatlinkshere-barrow' ) . ' '  .$this->skin->makeLinkObj($this->target, '', 'redirect=no' )."<br />\n");
 
-		$this->showIndirectLinks( 0, $this->target, $this->limit, $this->from, $this->dir );
+		$this->showIndirectLinks( 0, $this->target, $this->limit, $this->from, $this->back );
 	}
 
 	/**
@@ -67,20 +69,21 @@ class WhatLinksHerePage {
 	 * @param Title     $target     Target title
 	 * @param int       $limit      Number of entries to display
 	 * @param Title     $from       Display from this article ID
-	 * @param string    $dir        'next' or 'prev', whether $fromTitle is the start or end of the list
+	 * @param Title     $back       Display from this article ID at backwards scrolling
 	 * @private
 	 */
-	function showIndirectLinks( $level, $target, $limit, $from = 0, $dir = 'next' ) {
+	function showIndirectLinks( $level, $target, $limit, $from = 0, $back = 0 ) {
 		global $wgOut;
 		$fname = 'WhatLinksHerePage::showIndirectLinks';
+		$dbr = wfGetDB( DB_READ );
+		$options = array();
 
-		$dbr =& wfGetDB( DB_READ );
-
-		// Some extra validation
-		$from = intval( $from );
-		if ( !$from && $dir == 'prev' ) {
-			// Before start? No make sense
-			$dir = 'next';
+		$ns = $this->request->getIntOrNull( 'namespace' );
+		if ( isset( $ns ) ) {
+			$options['namespace'] = $ns;
+			$this->setNamespace( $options['namespace'] );
+		} else {
+			$options['namespace'] = '';
 		}
 
 		// Make the query
@@ -96,18 +99,18 @@ class WhatLinksHerePage {
 			'tl_title' => $target->getDBkey(),
 		);
 
+		if ( $this->namespace !== null ){
+			$plConds['page_namespace'] = (int)$this->namespace;
+			$tlConds['page_namespace'] = (int)$this->namespace;
+		}
+
 		if ( $from ) {
-			if ( 'prev' == $dir ) {
-				$offsetCond = "page_id < $from";
-				$options = array( 'ORDER BY page_id DESC' );
-			} else {
-				$offsetCond = "page_id >= $from";
-				$options = array( 'ORDER BY page_id' );
-			}
+			$offsetCond = "page_id >= $from";
 		} else {
 			$offsetCond = false;
-			$options = array( 'ORDER BY page_id,is_template DESC' );
 		}
+		$options['ORDER BY'] = 'page_id';
+
 		// Read an extra row as an at-end check
 		$queryLimit = $limit + 1;
 		$options['LIMIT'] = $queryLimit;
@@ -121,14 +124,37 @@ class WhatLinksHerePage {
 			$plConds, $fname, $options );
 		$tlRes = $dbr->select( array( 'templatelinks', 'page' ), $fields,
 			$tlConds, $fname, $options );
-
 		if ( !$dbr->numRows( $plRes ) && !$dbr->numRows( $tlRes ) ) {
-			if ( 0 == $level ) {
+			if ( 0 == $level && !isset( $this->namespace ) ) {
+				// really no links to here
 				$wgOut->addWikiText( wfMsg( 'nolinkshere', $this->target->getPrefixedText() ) );
+			} elseif ( 0 == $level && isset( $this->namespace ) ) {
+				// no links from requested namespace to here
+				$options = array(); // reinitialize for a further namespace search
+				$options['namespace'] = $this->namespace;
+				$options['target'] = $this->target->getPrefixedText();
+				list( $options['limit'], $options['offset']) = wfCheckLimits();
+				$wgOut->addHTML( $this->whatlinkshereForm( $options ) );
+				$wgOut->addWikiText( wfMsg( 'nolinkshere-ns', $this->target->getPrefixedText() ) );
 			}
 			return;
 		}
 
+		$options = array();
+		list( $options['limit'], $options['offset']) = wfCheckLimits();
+		if ( ( $ns = $this->request->getVal( 'namespace', null ) ) !== null && $ns !== '' && ctype_digit($ns) ) {
+			$options['namespace'] = intval( $ns );
+			$this->setNamespace( $options['namespace'] );
+		} else {
+			$options['namespace'] = '';
+			$this->setNamespace( null );
+		}
+		$options['offset'] = $this->request->getVal( 'offset' );
+		/* Offset must be an integral. */
+		if ( !strlen( $options['offset'] ) || !preg_match( '/^[0-9]+$/', $options['offset'] ) )
+		$options['offset'] = '';
+		$options['target'] = $this->target->getPrefixedDBkey();
+
 		// Read the rows into an array and remove duplicates
 		// templatelinks comes second so that the templatelinks row overwrites the
 		// pagelinks row, so we get (inclusion) rather than nothing
@@ -150,46 +176,27 @@ class WhatLinksHerePage {
 		$numRows = count( $rows );
 
 		// Work out the start and end IDs, for prev/next links
-		if ( $dir == 'prev' ) {
-			// Descending order
-			if ( $numRows > $limit ) {
-				// More rows available before these ones
-				// Get the ID from the next row past the end of the displayed set
-				$prevId = $rows[$limit]->page_id;
-				// Remove undisplayed rows
-				$rows = array_slice( $rows, 0, $limit );
-			} else {
-				// No more rows available before
-				$prevId = 0;
-			}
-			// Assume that the ID specified in $from exists, so there must be another page
-			$nextId = $from;
-
-			// Reverse order ready for display
-			$rows = array_reverse( $rows );
+		if ( $numRows > $limit ) {
+			// More rows available after these ones
+			// Get the ID from the last row in the result set
+			$nextId = $rows[$limit]->page_id;
+			// Remove undisplayed rows
+			$rows = array_slice( $rows, 0, $limit );
 		} else {
-			// Ascending
-			if ( $numRows > $limit ) {
-				// More rows available after these ones
-				// Get the ID from the last row in the result set
-				$nextId = $rows[$limit]->page_id;
-				// Remove undisplayed rows
-				$rows = array_slice( $rows, 0, $limit );
-			} else {
-				// No more rows after
-				$nextId = false;
-			}
-			$prevId = $from;
+			// No more rows after
+			$nextId = false;
 		}
+		$prevId = $from;
 
-		if ( 0 == $level ) {
+		if ( $level == 0 ) {
+			$wgOut->addHTML( $this->whatlinkshereForm( $options ) );
 			$wgOut->addWikiText( wfMsg( 'linkshere', $this->target->getPrefixedText() ) );
 		}
 		$isredir = wfMsg( 'isredirect' );
 		$istemplate = wfMsg( 'istemplate' );
 
 		if( $level == 0 ) {
-			$prevnext = $this->getPrevNext( $limit, $prevId, $nextId );
+			$prevnext = $this->getPrevNext( $limit, $prevId, $nextId, $options['namespace'] );
 			$wgOut->addHTML( $prevnext );
 		}
 
@@ -240,16 +247,21 @@ class WhatLinksHerePage {
 	function getPrevNext( $limit, $prevId, $nextId ) {
 		global $wgLang;
 		$fmtLimit = $wgLang->formatNum( $limit );
-		$prev = wfMsg( 'prevn', $fmtLimit );
-		$next = wfMsg( 'nextn', $fmtLimit );
+		$prev = wfMsgExt( 'whatlinkshere-prev', array( 'parsemag', 'escape' ), $fmtLimit );
+		$next = wfMsgExt( 'whatlinkshere-next', array( 'parsemag', 'escape' ), $fmtLimit );
+
+		$nsText = '';
+		if( is_int($this->namespace) ) {
+			$nsText = "&namespace={$this->namespace}";
+		}
 
 		if ( 0 != $prevId ) {
-			$prevLink = $this->makeSelfLink( $prev, "limit={$limit}&from={$prevId}&dir=prev" );
+			$prevLink = $this->makeSelfLink( $prev, "limit={$limit}&from={$this->back}{$nsText}" );
 		} else {
 			$prevLink = $prev;
 		}
 		if ( 0 != $nextId ) {
-			$nextLink = $this->makeSelfLink( $next, "limit={$limit}&from={$nextId}" );
+			$nextLink = $this->makeSelfLink( $next, "limit={$limit}&from={$nextId}&back={$prevId}{$nsText}" );
 		} else {
 			$nextLink = $next;
 		}
@@ -262,12 +274,42 @@ class WhatLinksHerePage {
 		return wfMsg( 'viewprevnext', $prevLink, $nextLink, $nums );
 	}
 
-	function numLink( $limit, $from ) {
+	function numLink( $limit, $from, $ns = null ) {
 		global $wgLang;
 		$query = "limit={$limit}&from={$from}";
+		if( is_int($this->namespace) ) { $query .= "&namespace={$this->namespace}";}
 		$fmtLimit = $wgLang->formatNum( $limit );
 		return $this->makeSelfLink( $fmtLimit, $query );
 	}
+
+	function whatlinkshereForm( $options ) {
+		global $wgScript, $wgTitle;
+
+		$options['title'] = $wgTitle->getPrefixedText();
+
+		$f = Xml::openElement( 'form', array( 'method' => 'get', 'action' => "$wgScript" ) ) .
+			'<fieldset>' .
+			Xml::element( 'legend', array(), wfMsg( 'whatlinkshere' ) );
+
+		foreach ( $options as $name => $value ) {
+			if( $name === 'namespace') continue;
+			$f .= "\t" . Xml::hidden( $name, $value ). "\n";
+		}
+
+		$f .= Xml::label( wfMsg( 'namespace' ), 'namespace' ) . ' ' .
+			Xml::namespaceSelector( $options['namespace'], '' ) .
+			Xml::submitButton( wfMsg( 'allpagessubmit' ) ) .
+			'</fieldset>' .
+			Xml::closeElement( 'form' ) . "\n";
+
+		return $f;
+	}
+
+	/** Set the namespace we are filtering on */
+	private function setNamespace( $ns ) {
+		$this->namespace = $ns;
+	}
+
 }
 
 ?>
