@@ -24,7 +24,7 @@ class StubObject {
 	}
 
 	static function isRealObject( $obj ) {
-		return is_object( $obj ) && !is_a( $obj, 'StubObject' );
+		return is_object( $obj ) && !($obj instanceof StubObject);
 	}
 
 	function _call( $name, $args ) {
@@ -35,7 +35,7 @@ class StubObject {
 	function _newObject() {
 		return wfCreateObject( $this->mClass, $this->mParams );
 	}
-	
+
 	function __call( $name, $args ) {
 		return $this->_call( $name, $args );
 	}
@@ -100,7 +100,8 @@ class StubUserLang extends StubObject {
 		}	 
 
 		# Validate $code
-		if( empty( $code ) || !preg_match( '/^[a-z]+(-[a-z]+)?$/', $code ) ) {
+		if( empty( $code ) || !preg_match( '/^[a-z-]+$/', $code ) ) {
+			wfDebug( "Invalid user language code\n" );
 			$code = $wgContLanguageCode;
 		}
 
