@@ -1,12 +1,10 @@
 <?php
 /**
  *
- * @package MediaWiki
  */
 
 /**
  *
- * @package MediaWiki
  */
 class WatchedItem {
 	var $mTitle, $mUser;
@@ -31,32 +29,18 @@ class WatchedItem {
 		return $wl;
 	}
 
-	/**
-	 * Returns the memcached key for this item
-	 */
-	function watchKey() {
-		global $wgDBname;
-		return "$wgDBname:watchlist:user:$this->id:page:$this->ns:$this->ti";
-	}
-
 	/**
 	 * Is mTitle being watched by mUser?
 	 */
 	function isWatched() {
 		# Pages and their talk pages are considered equivalent for watching;
 		# remember that talk namespaces are numbered as page namespace+1.
-		global $wgMemc;
 		$fname = 'WatchedItem::isWatched';
 
-		$key = $this->watchKey();
-		$iswatched = $wgMemc->get( $key );
-		if( is_integer( $iswatched ) ) return $iswatched;
-
-		$dbr =& wfGetDB( DB_SLAVE );
+		$dbr = wfGetDB( DB_SLAVE );
 		$res = $dbr->select( 'watchlist', 1, array( 'wl_user' => $this->id, 'wl_namespace' => $this->ns,
 			'wl_title' => $this->ti ), $fname );
 		$iswatched = ($dbr->numRows( $res ) > 0) ? 1 : 0;
-		$wgMemc->set( $key, $iswatched );
 		return $iswatched;
 	}
 
@@ -69,7 +53,7 @@ class WatchedItem {
 
 		// Use INSERT IGNORE to avoid overwriting the notification timestamp
 		// if there's already an entry for this page
-		$dbw =& wfGetDB( DB_MASTER );
+		$dbw = wfGetDB( DB_MASTER );
 		$dbw->insert( 'watchlist',
 		  array(
 		    'wl_user' => $this->id,
@@ -88,18 +72,15 @@ class WatchedItem {
 			'wl_notificationtimestamp' => NULL
 		  ), $fname, 'IGNORE' );
 
-		global $wgMemc;
-		$wgMemc->set( $this->watchkey(), 1 );
 		wfProfileOut( $fname );
 		return true;
 	}
 
 	function removeWatch() {
-		global $wgMemc;
 		$fname = 'WatchedItem::removeWatch';
 
 		$success = false;
-		$dbw =& wfGetDB( DB_MASTER );
+		$dbw = wfGetDB( DB_MASTER );
 		$dbw->delete( 'watchlist',
 			array(
 				'wl_user' => $this->id,
@@ -126,9 +107,6 @@ class WatchedItem {
 		if ( $dbw->affectedRows() ) {
 			$success = true;
 		}
-		if ( $success ) {
-			$wgMemc->set( $this->watchkey(), 0 );
-		}
 		return $success;
 	}
 
@@ -156,7 +134,7 @@ class WatchedItem {
 		$oldtitle = $ot->getDBkey();
 		$newtitle = $nt->getDBkey();
 
-		$dbw =& wfGetDB( DB_MASTER );
+		$dbw = wfGetDB( DB_MASTER );
 		$res = $dbw->select( 'watchlist', 'wl_user',
 			array( 'wl_namespace' => $oldnamespace, 'wl_title' => $oldtitle ),
 			$fname, 'FOR UPDATE'
