@@ -1,12 +1,11 @@
 <?php
 /** Croatian (hrvatski)
   *
-  * @package MediaWiki
-  * @subpackage Language
+  * @addtogroup Language
   */
 
 class LanguageHr extends Language {
-	function convertPlural( $count, $wordform1, $wordform2, $wordform3) {
+	function convertPlural( $count, $wordform1, $wordform2, $wordform3, $w4, $w5) {
 		$count = str_replace ('.', '', $count);
 		if ($count > 10 && floor(($count % 100) / 10) == 1) {
 			return $wordform3;
