@@ -13,8 +13,7 @@ require_once( 'includes/SkinTemplate.php' );
 /**
  * Inherit main code from SkinTemplate, set the CSS and template filter.
  * @todo document
- * @package MediaWiki
- * @subpackage Skins
+ * @addtogroup Skins
  */
 class SkinHTMLDump extends SkinTemplate {
 	/** Using monobook. */
@@ -76,7 +75,7 @@ class SkinHTMLDump extends SkinTemplate {
 
 		if ( $nt->getNamespace() == NS_CATEGORY ) {
 			# Determine if the category has any articles in it
-			$dbr =& wfGetDB( DB_SLAVE );
+			$dbr = wfGetDB( DB_SLAVE );
 			$hasMembers = $dbr->selectField( 'categorylinks', '1', 
 				array( 'cl_to' => $nt->getDBkey() ), __METHOD__ );
 			if ( $hasMembers ) {
@@ -93,8 +92,7 @@ class SkinHTMLDump extends SkinTemplate {
 
 /**
  * @todo document
- * @package MediaWiki
- * @subpackage Skins
+ * @addtogroup Skins
  */
 class HTMLDumpTemplate extends QuickTemplate {
 	/**
